==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAudioRoleControl_shell.h <==
#ifndef QAUDIOROLECONTROL_SHELL_H
#define QAUDIOROLECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiorolecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtJambi/RegistryAPI>


class QAudioRoleControl_shell : public QAudioRoleControl, public QtJambiShellInterface
{
public:
    QAudioRoleControl_shell(QObject* parent0 = nullptr);
    ~QAudioRoleControl_shell() override;

    QAudio::Role audioRole() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setAudioRole(QAudio::Role role0) override;
    QList<QAudio::Role> supportedAudioRoles() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioRoleControl_access : public QAudioRoleControl
{
    jint __qt_audioRole(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAudioRole_QAudio_Role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0);
    jobject __qt_supportedAudioRoles(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QAUDIOROLECONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QAudioRoleControl_shell.h <==
#ifndef QAUDIOROLECONTROL_SHELL_H
#define QAUDIOROLECONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiorolecontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudio.h>
#include <QtJambi/RegistryAPI>


class QAudioRoleControl_shell : public QAudioRoleControl, public QtJambiShellInterface
{
public:
    QAudioRoleControl_shell(QObject* parent0 = nullptr);
    ~QAudioRoleControl_shell() override;

    QAudio::Role audioRole() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setAudioRole(QAudio::Role role0) override;
    QList<QAudio::Role> supportedAudioRoles() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioRoleControl_access : public QAudioRoleControl
{
    jint __qt_audioRole_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAudioRole_QAudio_Role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint role0);
    jobject __qt_supportedAudioRoles_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QAUDIOROLECONTROL_SHELL_H
